Libre Caslon Text is optimized for web body text (typically set at 16px), whilst the companion family Libre Caslon Display is optimized for web headlines.

Libre Caslon Text was specifically tailored to be used for web body text (typically set at 16px). It can be used at very small sizes and will still be readable on your website.

Another big difference is that pretty much all other digital Caslons revivals are based on 18th Century specimens by William Caslon I and William Caslon II. Libre Caslon, instead, is based on hand lettering artist Caslon interpretations typical of 1950s advertising.

This font was upgraded in early 2020 and is now available as a variable font.

To contribute, see github.com/thundernixon/Libre-Caslon